# coding: utf-8

import pytest

from django.contrib.auth.models import User
from django.contrib.sites.models import Site

from registration.models import RegistrationProfile

from ..mails import (
    send_activation_email,
    send_activation_pending_email,
    send_confirmation_email,
)


@pytest.mark.django_db
def test_send_activation_email(mocker):
    user_info = {
        User.USERNAME_FIELD: 'alice',
        'password': 'swordfish',
        'email': 'alice@example.com'
    }

    new_user = User.objects.create_user(**user_info)
    profile = RegistrationProfile.objects.create_profile(new_user)
    site = Site.objects.get_current()

    mock = mocker.patch('accounts.mails.send_mail')
    assert not mock.called

    send_activation_email(new_user, profile, site)
    assert mock.called


@pytest.mark.django_db
def test_send_activation_pending_email(mocker):
    user_info = {
        User.USERNAME_FIELD: 'alice',
        'password': 'swordfish',
        'email': 'alice@example.com'
    }

    new_user = User.objects.create_user(**user_info)
    profile = RegistrationProfile.objects.create_profile(new_user)
    site = Site.objects.get_current()

    mock = mocker.patch.object(new_user, "email_user")
    assert not mock.called

    send_activation_pending_email(new_user, site, profile)
    assert mock.called


@pytest.mark.django_db
def test_send_confirmation_email(mocker):
    user_info = {
        User.USERNAME_FIELD: 'alice',
        'password': 'swordfish',
        'email': 'alice@example.com'
    }

    new_user = User.objects.create_user(**user_info)
    site = Site.objects.get_current()

    mock = mocker.patch.object(new_user, "email_user")
    assert not mock.called

    send_confirmation_email(new_user, site)
    assert mock.called
