# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.conf.urls import include, url

from .views import (
    CustomActivationView,
    CustomRegistrationView,
    RegistrationActivationCompleteView,
    RegistrationClosedView,
    RegistrationCompleteView,

    custom_login,
    custom_password_change,
    custom_password_reset,
    custom_password_reset_confirm,
)

urlpatterns = [
    url(r'^activate/complete/$',
        RegistrationActivationCompleteView.as_view(),
        name='registration_activation_complete'),
    # Activation keys get matched by \w+ instead of the more specific
    # [a-fA-F0-9]{40} because a bad activation key should still get to the
    # view; that way it can return a sensible "invalid key" message instead of
    # a confusing 404.
    url(r'^activate/(?P<activation_key>\w+)/$',
        CustomActivationView.as_view(),
        name='registration_activate'),
    url(r'^register/$',
        CustomRegistrationView.as_view(),
        name='registration_register'),
    url(r'^register/complete/$',
        RegistrationCompleteView.as_view(),
        name='registration_complete'),
    url(r'^register/closed/$',
        RegistrationClosedView.as_view(),
        name='registration_closed'),

    # Override some urls from "registration.auth_urls"
    url(r'^login/$',
        custom_login,
        name='auth_login'),
    url(r'^password/change/$',
        custom_password_change,
        name='auth_password_change'),
    url(r'^password/reset/$',
        custom_password_reset,
        name='auth_password_reset'),
    url(r'^password/reset/confirm/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$',
        custom_password_reset_confirm,
        name='auth_password_reset_confirm'),

    url(r'', include('registration.auth_urls')),
]
